@@ -127,10 +127,9 @@ data types and properties. The following list details the most important ones:
 """
 # endregion
 from pathlib import Path
-from typing import List, Optional, Union
+from typing import Dict, List, Optional, Union
 
 from DataDriver import DataDriver
-from DataDriver.AbstractReaderClass import AbstractReaderClass
 from requests.auth import AuthBase
 from robot.api.deco import library
 
@@ -158,6 +157,7 @@ class OpenApiDriver(OpenApiExecutors, DataDriver):
         password: str = "",
         security_token: str = "",
         auth: Optional[AuthBase] = None,
+        extra_headers: Optional[Dict[str, str]] = None,
         response_validation: ValidationLevel = ValidationLevel.WARN,
         disable_server_validation: bool = True,
         require_body_for_invalid_url: bool = False,
@@ -202,6 +202,11 @@ class OpenApiDriver(OpenApiExecutors, DataDriver):
         A [https://docs.python-requests.org/en/latest/api/#authentication | requests AuthBase instance]
         to be used for authentication instead of the ``username`` and ``password``.
 
+        === extra_headers ===
+        A dictionary with extra / custom headers that will be send with every request.
+        This parameter can be used to send headers that are not documented in the
+        openapi document.
+
         === response_validation ===
         By default, a ``WARN`` is logged when the Response received after a Request does not
         comply with the schema as defined in the openapi document for the given operation. The
@@ -248,6 +253,7 @@ class OpenApiDriver(OpenApiExecutors, DataDriver):
             password=password,
             security_token=security_token,
             auth=auth,
+            extra_headers=extra_headers,
             response_validation=response_validation,
             disable_server_validation=disable_server_validation,
             require_body_for_invalid_url=require_body_for_invalid_url,
@@ -257,23 +263,16 @@ class OpenApiDriver(OpenApiExecutors, DataDriver):
         endpoints = self.openapi_spec["paths"]
         DataDriver.__init__(
             self,
-            # FIXME: Enable when DataDriver accepts AbstractReaderClass subclasses
-            # reader_class=OpenApiReader
-            reader_class="openapi_reader",
+            reader_class=OpenApiReader,
             endpoints=endpoints,
             ignored_endpoints=ignored_endpoints,
             ignored_responses=ignored_responses,
             ignored_testcases=ignored_testcases,
         )
 
-    # FIXME: Hack to allow directly loading the OpenApiReader - remove when DataDriver
-    # accepts an AbstractReaderClass subclass as reader_class argument
-    def _data_reader(self) -> AbstractReaderClass:
-        return OpenApiReader(self.reader_config)
-
 
 class DocumentationGenerator(OpenApiDriver):
-    """Helper class to be able to generate curated libdoc and libspec documentation."""
+    __doc__ = OpenApiDriver.__doc__
 
     @staticmethod
     def get_keyword_names():
